#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File   : __init__.py.py
# @Author : mocobk
# @Email  : mailmzb@qq.com
# @Time   : 2019/9/13 19:52
from .logger import Logger as logger

__all__ = ['logger']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File   : ilogger.py
# @Author : mocobk
# @Email  : mailmzb@qq.com
# @Time   : 2019/9/13 19:52
import logging
import sys

default_fmt = '[%(asctime)s]%(levelname)7s: %(message)s'


def _stream_handler():
    handler = logging.StreamHandler(stream=sys.stdout)
    formatter = logging.Formatter(default_fmt)
    handler.setFormatter(formatter)
    return handler


_logger = logging.getLogger(__name__)
_logger.addHandler(_stream_handler())
_logger.setLevel(logging.INFO)


class Logger:
    NOTSET = logging.NOTSET
    DEBUG = logging.DEBUG
    INFO = logging.INFO
    WARNING = logging.WARNING
    WARN = logging.WARN
    ERROR = logging.ERROR
    CRITICAL = logging.CRITICAL

    @classmethod
    def setLevel(cls, level):
        return _logger.setLevel(level)

    @classmethod
    def setFormatter(cls, fmt=default_fmt, datefmt=None, style='%'):
        _handler = _logger.handlers[0]
        _handler.setFormatter(logging.Formatter(fmt, datefmt, style))

    @classmethod
    def debug(cls, msg, *args, **kwargs):
        pass

    @classmethod
    def info(cls, msg, *args, **kwargs):
        pass

    @classmethod
    def warn(cls, msg, *args, **kwargs):
        pass

    @classmethod
    def warning(cls, msg, *args, **kwargs):
        pass

    @classmethod
    def error(cls, msg, *args, **kwargs):
        pass

    @classmethod
    def critical(cls, msg, *args, **kwargs):
        pass


setattr(Logger, 'debug', _logger.debug)
setattr(Logger, 'info', _logger.info)
setattr(Logger, 'warn', _logger.warn)
setattr(Logger, 'warning', _logger.warning)
setattr(Logger, 'error', _logger.error)
setattr(Logger, 'critical', _logger.critical)



# -*- coding:utf-8 -*-  
# __auth__ = mocobk
# email: mailmzb@qq.com

import setuptools

with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name="ilogger",
    version="0.0.2",
    author="mocobk",
    author_email="mocobk@163.com",
    description="超简单的日志模块，导入即用",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mocobk/ilogger",
    packages=['ilogger'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)